import * as assembly from './schema';
export declare const VERSION_MISMATCH: string;
/**
 * Protocol utility class.
 */
export declare class Manifest {
    /**
     * Save manifest to file.
     *
     * @param manifest - manifest.
     */
    static save(manifest: assembly.AssemblyManifest, filePath: string): void;
    /**
     * Load manifest from file.
     *
     * @param filePath - path to the manifest file.
     */
    static load(filePath: string): assembly.AssemblyManifest;
    /**
     * Fetch the current schema version number.
     */
    static version(): string;
    private static schema;
    private static validate;
    /**
     * This requires some explaining...
     *
     * We previously used `{ Key, Value }` for the object that represents a stack tag. (Notice the casing)
     * @link https://github.com/aws/aws-cdk/blob/v1.27.0/packages/aws-cdk/lib/api/cxapp/stacks.ts#L427.
     *
     * When that object moved to this package, it had to be JSII compliant, which meant the property
     * names must be `camelCased`, and not `PascalCased`. This meant it no longer matches the structure in the `manifest.json` file.
     * In order to support current manifest files, we have to translate the `PascalCased` representation to the new `camelCased` one.
     *
     * Note that the serialization itself still writes `PascalCased` because it relates to how CloudFormation expects it.
     *
     * Ideally, we would start writing the `camelCased` and translate to how CloudFormation expects it when needed. But this requires nasty
     * backwards-compatibility code and it just doesn't seem to be worth the effort.
     */
    private static patchStackTags;
    private constructor();
}
